@@ -1,7 +1,7 @@
 package Perinci::Object::EnvResultMulti;
 
-our $DATE = '2016-12-28'; # DATE
-our $VERSION = '0.29'; # VERSION
+our $DATE = '2018-10-18'; # DATE
+our $VERSION = '0.310'; # VERSION
 
 use 5.010;
 use strict;
@@ -22,7 +22,7 @@ sub add_result {
     my $num_nok = 0;
 
     push @{ ${$self}->[3]{results} },
-        {%{ $extra // {} }, status=>$status, message=>$message};
+        {status=>$status, message=>$message, %{ $extra // {} }};
     for (@{ ${$self}->[3]{results} // [] }) {
         if ($_->{status} =~ /\A(2|304)/) {
             $num_ok++;
@@ -35,7 +35,16 @@ sub add_result {
             ${$self}->[0] = 207;
             ${$self}->[1] = "Partial success";
         } else {
-            ${$self}->[0] = 200;
+            my $overall_status = 200;
+            my %statuses;
+            for (@{ ${$self}->[3]{results} // []}) {
+                $statuses{ $_->{status} }++;
+            }
+            if (keys %statuses == 1) {
+                my @tmp = keys %statuses;
+                $overall_status = $tmp[0];
+            }
+            ${$self}->[0] = $overall_status;
             ${$self}->[1] = "All success";
         }
     } else {
@@ -59,7 +68,7 @@ Perinci::Object::EnvResultMulti - Represent enveloped result (multistatus)
 
 =head1 VERSION
 
-This document describes version 0.29 of Perinci::Object::EnvResultMulti (from Perl distribution Perinci-Object), released on 2016-12-28.
+This document describes version 0.310 of Perinci::Object::EnvResultMulti (from Perl distribution Perinci-Object), released on 2018-10-18.
 
 =head1 SYNOPSIS
 
@@ -141,7 +150,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
